summaryrefslogtreecommitdiffstats
path: root/generic/tclExecute.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclExecute.c')
-rw-r--r--generic/tclExecute.c7
1 files changed, 5 insertions, 2 deletions
diff --git a/generic/tclExecute.c b/generic/tclExecute.c
index c8efbce..227cbca 100644
--- a/generic/tclExecute.c
+++ b/generic/tclExecute.c
@@ -11,7 +11,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclExecute.c,v 1.37 2001/11/16 20:14:27 msofer Exp $
+ * RCS: @(#) $Id: tclExecute.c,v 1.38 2001/11/20 16:36:06 msofer Exp $
*/
#include "tclInt.h"
@@ -793,12 +793,15 @@ TclExecuteByteCode(interp, codePtr)
preservedStack = stackPtr;
/*
* Finally, let TclEvalObjvInternal handle the command.
*/
+ iPtr->numLevels--;
DECACHE_STACK_INFO();
result = TclEvalObjvInternal(interp, objc, objv, bytes, length, 0);
CACHE_STACK_INFO();
+ iPtr->numLevels++;
/*
* If the old stack is going to be released, it is
@@ -793,12 +793,15 @@ TclExecuteByteCode(interp, codePtr)
preservedStack = stackPtr;
/*
- * Finally, let TclEvalObjvInternal handle the command.
+ * Finally, let TclEvalObjvInternal handle the command. As it
+ * will increase the numLevels, decrease them here to compensate.
*/